from _typeshed import SupportsWrite
from collections.abc import Iterator, Mapping
from typing import Final

BIG_ENDIAN_PLATFORM: bool
INET_PTON: Final = 1
ZEROFILL: Final = 2
NOHOST: Final = 4
INET_ATON: Final = 8

class AddrFormatError(Exception): ...
class AddrConversionError(Exception): ...
class NotRegisteredError(Exception): ...

class Subscriber:
    def update(self, data) -> None: ...

class PrettyPrinter(Subscriber):
    fh: SupportsWrite[str]
    write_eol: bool
    def __init__(self, fh: SupportsWrite[str] = ..., write_eol: bool = True) -> None: ...
    def update(self, data: object) -> None: ...

class Publisher:
    subscribers: list[Subscriber]
    def __init__(self) -> None: ...
    def attach(self, subscriber: Subscriber) -> None: ...
    def detach(self, subscriber: Subscriber) -> None: ...
    def notify(self, data: object) -> None: ...

class DictDotLookup:
    def __init__(self, d: Mapping[str, object]) -> None: ...
    def __getitem__(self, name: str) -> object: ...
    def __iter__(self) -> Iterator[str]: ...



from _typeshed import ConvertibleToInt
from typing import ClassVar, Literal, overload
from typing_extensions import Self

from netaddr.core import DictDotLookup
from netaddr.ip import IPAddress
from netaddr.strategy.eui48 import mac_eui48
from netaddr.strategy.eui64 import eui64_base

class BaseIdentifier:
    __slots__ = ("_value", "__weakref__")
    def __init__(self) -> None: ...
    def __int__(self) -> int: ...
    def __index__(self) -> int: ...

class OUI(BaseIdentifier):
    __slots__ = ("records",)
    records: list[dict[str, object]]
    def __init__(self, oui: str | int) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    @property
    def reg_count(self) -> int: ...
    def registration(self, index: int = 0) -> DictDotLookup: ...

class IAB(BaseIdentifier):
    __slots__ = ("record",)
    IAB_EUI_VALUES: ClassVar[tuple[int, int]]
    @classmethod
    def split_iab_mac(cls, eui_int: int, strict: bool = False) -> tuple[int, int]: ...
    record: dict[str, object]
    def __init__(self, iab: str | int, strict: bool = False) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def registration(self) -> DictDotLookup: ...

class EUI(BaseIdentifier):
    __slots__ = ("_module", "_dialect")
    def __init__(
        self, addr: EUI | int | str, version: int | None = None, dialect: type[mac_eui48 | eui64_base] | None = None
    ) -> None: ...
    @property
    def value(self) -> int: ...
    @value.setter
    def value(self, value: ConvertibleToInt) -> None: ...
    @property
    def dialect(self) -> type[mac_eui48 | eui64_base]: ...
    @dialect.setter
    def dialect(self, value: type[mac_eui48 | eui64_base] | None) -> None: ...
    @property
    def oui(self) -> OUI: ...
    @property
    def ei(self) -> str: ...
    def is_iab(self) -> bool: ...
    @property
    def iab(self) -> IAB | None: ...
    @property
    def version(self) -> Literal[48, 64]: ...
    @overload
    def __getitem__(self, idx: int) -> int: ...
    @overload
    def __getitem__(self, idx: slice) -> list[int]: ...
    @overload
    def __getitem__(self, idx: int | slice) -> int | list[int]: ...
    def __setitem__(self, idx: int, value: int) -> None: ...
    def __hash__(self) -> int: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __lt__(self, other: EUI | int | str) -> bool: ...
    def __le__(self, other: EUI | int | str) -> bool: ...
    def __gt__(self, other: EUI | int | str) -> bool: ...
    def __ge__(self, other: EUI | int | str) -> bool: ...
    def bits(self, word_sep: str | None = None) -> str: ...
    @property
    def packed(self) -> bytes: ...
    @property
    def words(self) -> tuple[int, ...]: ...
    @property
    def bin(self) -> str: ...
    def eui64(self) -> Self: ...
    def modified_eui64(self) -> Self: ...
    def ipv6(self, prefix: ConvertibleToInt) -> IPAddress: ...
    def ipv6_link_local(self) -> IPAddress: ...
    @property
    def info(self) -> DictDotLookup: ...
    def format(self, dialect: type[mac_eui48 | eui64_base] | None = None) -> str: ...



from typing_extensions import TypeGuard

from netaddr.ip import IPAddress, IPNetwork, IPRange, _IPAddressAddr, _IPNetworkAddr

def valid_glob(ipglob: object) -> TypeGuard[str]: ...
def glob_to_iptuple(ipglob: str) -> tuple[IPAddress, IPAddress]: ...
def glob_to_iprange(ipglob: str) -> IPRange: ...
def iprange_to_globs(start: _IPAddressAddr, end: _IPAddressAddr) -> list[str]: ...
def glob_to_cidrs(ipglob: str) -> list[IPNetwork]: ...
def cidr_to_glob(cidr: _IPNetworkAddr) -> str: ...

class IPGlob(IPRange):
    __slots__ = ("_glob",)
    def __init__(self, ipglob: str) -> None: ...
    @property
    def glob(self) -> str: ...
    @glob.setter
    def glob(self, value: str) -> None: ...



from _typeshed import Unused
from collections.abc import Iterable, Sequence
from socket import AddressFamily
from typing import Literal

from netaddr.core import INET_PTON as INET_PTON, ZEROFILL as ZEROFILL

width: Literal[32]
word_size: Literal[8]
word_fmt: Literal["%d"]
word_sep: Literal["."]
family: Literal[AddressFamily.AF_INET]
family_name: Literal["IPv4"]
version: Literal[4]
word_base: Literal[10]
max_int: int
num_words: Literal[4]
max_word: int
prefix_to_netmask: dict[int, int]
netmask_to_prefix: dict[int, int]
prefix_to_hostmask: dict[int, int]
hostmask_to_prefix: dict[int, int]

def valid_str(addr: str, flags: int = 0) -> bool: ...
def str_to_int(addr: str, flags: int = 0) -> int: ...
def int_to_str(int_val: int, dialect: Unused = None) -> str: ...
def int_to_arpa(int_val: int) -> str: ...
def int_to_packed(int_val: int) -> bytes: ...
def packed_to_int(packed_int: bytes) -> int: ...
def valid_words(words: Iterable[int]) -> bool: ...
def int_to_words(int_val: int) -> tuple[int, ...]: ...
def words_to_int(words: Sequence[int]) -> int: ...
def valid_bits(bits: str) -> bool: ...
def bits_to_int(bits: str) -> int: ...
def int_to_bits(int_val: int, word_sep: str | None = None) -> str: ...
def valid_bin(bin_val: str) -> bool: ...
def int_to_bin(int_val: int) -> str: ...
def bin_to_int(bin_val: str) -> int: ...
def expand_partial_address(addr: str) -> str: ...



from collections.abc import Iterable, Sequence
from typing import ClassVar, Final, Literal

from netaddr.fbsocket import AF_INET6

OPT_IMPORTS: bool
width: Literal[128]
word_size: Literal[16]
word_sep: Literal[":"]
family: Final = AF_INET6
family_name: Literal["IPv6"]
version: Literal[6]
word_base: Literal[16]
max_int: int
num_words: Literal[8]
max_word: int
prefix_to_netmask: dict[int, int]
netmask_to_prefix: dict[int, int]
prefix_to_hostmask: dict[int, int]
hostmask_to_prefix: dict[int, int]

class ipv6_compact:
    word_fmt: ClassVar[str]
    compact: ClassVar[bool]

class ipv6_full(ipv6_compact): ...
class ipv6_verbose(ipv6_compact): ...

def valid_str(addr: str, flags: int = 0) -> bool: ...
def str_to_int(addr: str, flags: int = 0) -> int: ...
def int_to_str(int_val: int, dialect: type[ipv6_compact] | None = None) -> str: ...
def int_to_arpa(int_val: int) -> str: ...
def int_to_packed(int_val: int) -> bytes: ...
def packed_to_int(packed_int: bytes) -> int: ...
def valid_words(words: Iterable[int]) -> bool: ...
def int_to_words(int_val: int, num_words: int | None = None, word_size: int | None = None) -> tuple[int, ...]: ...
def words_to_int(words: Sequence[int]) -> int: ...
def valid_bits(bits: str) -> bool: ...
def bits_to_int(bits: str) -> int: ...
def int_to_bits(int_val: int, word_sep: str | None = None) -> str: ...
def valid_bin(bin_val: str) -> bool: ...
def int_to_bin(int_val: int) -> str: ...
def bin_to_int(bin_val: str) -> int: ...



from netaddr.contrib.subnet_splitter import SubnetSplitter as SubnetSplitter
from netaddr.core import (
    INET_ATON as INET_ATON,
    INET_PTON as INET_PTON,
    NOHOST as NOHOST,
    ZEROFILL as ZEROFILL,
    AddrConversionError as AddrConversionError,
    AddrFormatError as AddrFormatError,
    NotRegisteredError as NotRegisteredError,
)
from netaddr.eui import EUI as EUI, IAB as IAB, OUI as OUI
from netaddr.ip import (
    IPAddress as IPAddress,
    IPNetwork as IPNetwork,
    IPRange as IPRange,
    all_matching_cidrs as all_matching_cidrs,
    cidr_abbrev_to_verbose as cidr_abbrev_to_verbose,
    cidr_exclude as cidr_exclude,
    cidr_merge as cidr_merge,
    iprange_to_cidrs as iprange_to_cidrs,
    iter_iprange as iter_iprange,
    iter_unique_ips as iter_unique_ips,
    largest_matching_cidr as largest_matching_cidr,
    smallest_matching_cidr as smallest_matching_cidr,
    spanning_cidr as spanning_cidr,
)
from netaddr.ip.glob import (
    IPGlob as IPGlob,
    cidr_to_glob as cidr_to_glob,
    glob_to_cidrs as glob_to_cidrs,
    glob_to_iprange as glob_to_iprange,
    glob_to_iptuple as glob_to_iptuple,
    iprange_to_globs as iprange_to_globs,
    valid_glob as valid_glob,
)
from netaddr.ip.nmap import iter_nmap_range as iter_nmap_range, valid_nmap_range as valid_nmap_range
from netaddr.ip.rfc1924 import base85_to_ipv6 as base85_to_ipv6, ipv6_to_base85 as ipv6_to_base85
from netaddr.ip.sets import IPSet as IPSet
from netaddr.strategy.eui48 import (
    mac_bare as mac_bare,
    mac_cisco as mac_cisco,
    mac_eui48 as mac_eui48,
    mac_pgsql as mac_pgsql,
    mac_unix as mac_unix,
    mac_unix_expanded as mac_unix_expanded,
    valid_str as valid_mac,
)
from netaddr.strategy.eui64 import (
    eui64_bare as eui64_bare,
    eui64_base as eui64_base,
    eui64_cisco as eui64_cisco,
    eui64_unix as eui64_unix,
    eui64_unix_expanded as eui64_unix_expanded,
    valid_str as valid_eui64,
)
from netaddr.strategy.ipv4 import expand_partial_address as expand_partial_ipv4_address, valid_str as valid_ipv4
from netaddr.strategy.ipv6 import (
    ipv6_compact as ipv6_compact,
    ipv6_full as ipv6_full,
    ipv6_verbose as ipv6_verbose,
    valid_str as valid_ipv6,
)

__all__ = [
    "AddrConversionError",
    "AddrFormatError",
    "NotRegisteredError",
    "ZEROFILL",
    "INET_ATON",
    "INET_PTON",
    "NOHOST",
    "IPAddress",
    "IPNetwork",
    "IPRange",
    "all_matching_cidrs",
    "cidr_abbrev_to_verbose",
    "cidr_exclude",
    "cidr_merge",
    "iprange_to_cidrs",
    "iter_iprange",
    "iter_unique_ips",
    "largest_matching_cidr",
    "smallest_matching_cidr",
    "spanning_cidr",
    "IPSet",
    "IPGlob",
    "cidr_to_glob",
    "glob_to_cidrs",
    "glob_to_iprange",
    "glob_to_iptuple",
    "iprange_to_globs",
    "valid_glob",
    "valid_nmap_range",
    "iter_nmap_range",
    "base85_to_ipv6",
    "ipv6_to_base85",
    "EUI",
    "IAB",
    "OUI",
    "valid_ipv4",
    "valid_ipv6",
    "ipv6_compact",
    "ipv6_full",
    "ipv6_verbose",
    "mac_eui48",
    "mac_unix",
    "mac_unix_expanded",
    "mac_cisco",
    "mac_bare",
    "mac_pgsql",
    "valid_mac",
    "eui64_base",
    "eui64_unix",
    "eui64_unix_expanded",
    "eui64_cisco",
    "eui64_bare",
    "valid_eui64",
    "SubnetSplitter",
    "expand_partial_ipv4_address",
]

__version__: str
VERSION: tuple[int, ...]
STATUS: str




from setuptools import setup

setup(package_data={'netaddr-stubs': ['__init__.pyi', 'cli.pyi', 'compat.pyi', 'contrib/__init__.pyi', 'contrib/subnet_splitter.pyi', 'core.pyi', 'eui/__init__.pyi', 'eui/ieee.pyi', 'fbsocket.pyi', 'ip/__init__.pyi', 'ip/glob.pyi', 'ip/iana.pyi', 'ip/nmap.pyi', 'ip/rfc1924.pyi', 'ip/sets.pyi', 'strategy/__init__.pyi', 'strategy/eui48.pyi', 'strategy/eui64.pyi', 'strategy/ipv4.pyi', 'strategy/ipv6.pyi', 'METADATA.toml', 'py.typed']})
